darkhistory.history.reionization.coll\_ion\_cooling\_rate
=========================================================

.. currentmodule:: darkhistory.history.reionization

.. autofunction:: coll_ion_cooling_rate